[](https://img.shields.io/pypi/pyversions/gklr.svg)
[![Built Status](https://api.cirrus-ci.com/github/JoseAngelMartinB/gklr.svg?branch=main)](https://cirrus-ci.com/github/JoseAngelMartinB/gklr)
[![Coveralls](https://img.shields.io/coveralls/github/JoseAngelMartinB/gklr/main.svg)](https://coveralls.io/r/JoseAngelMartinB/gklr)
[![PyPI-Server](https://img.shields.io/pypi/v/gklr.svg)](https://pypi.org/project/gklr/)
[![Conda-Forge](https://img.shields.io/conda/vn/conda-forge/gklr.svg)](https://anaconda.org/conda-forge/gklr)
![Licence](https://img.shields.io/badge/Licence-MIT-blue)


# GKLR

Generalized Kernel Logistic Regression.


## Description

Generalized Kernel Logistic Regression.


## Installation

Under construction...


## Authors

GKLR was mainly developed by José Ángel Martín Baos from the University of
Castilla-La Mancha (JoseAngel.Martin@uclm.es). The main authors of this
package are listed in the [AUTHORS](AUTHORS.md) file.


## Known Issues
There are no known issues at this moment.


## License
MIT license
